## Vektorplotter ReadMe
##### Version
v2.0 (Pre-Alpha)

###  Beschreibung

Vektorplotter ist eine Software zur Berechnung von geometrischer Probleme, sowie zur Visualiserung von 2D und 3D Objekten innerhalb eines kartesischen Koordinatensystems.

### Starten von Vektorplotter (Mac & Linux)

1. Python (Version 3.8.7+) installieren
1. Zip Datei entpacken
1. Terminal öffnen
1. "python3 Verzeichnis von Vektorplotter/main.py" eingeben

### Starten von Vektorplotter (Windows)

1. Python (Version 3.8.7+) installieren
1. Zip Datei entpacken
1. Terminal öffnen
1. "python3 Verzeichnis von Vektorplotter/main.py" eingeben

### Benutzung 

Die Software Vektorplotter sollte bei Eingabe von Funktionen der analytischen Geometrie:
* Schnittpunkte berechnen können
* Ebenen aufstellen könnnen
* Geraden aufstellen können
* Vektoren addieren können
* Vektoren subtrahieren können
* Vektoren mit einem Skalar multiplizieren können
* Ein Kreuzprodukt bilden können
* Schnittwinkel berechnen können 

### Support
Bei Problemen und Nachfragen erreichen sie den Support unter:

bru1093517@phormsstudent.de
bru1093982@phormsstudent.net
kag1093737@phormsstudent.net

### Zukünftige Releases 

In der Zukunft wird eine vollfunktionsfähige grafische Oberfläche releast. 

### Autoren

Die Software wird entwickelt von:

Benjamin Brumm, Finn Brunke und Julian Kagermann

### Lizenz 

Die Lizenz berechtigt den Kunden zur Einzelnutzung des Vektorplotters im Rahmen eines normalen Gebrauchs. Dieser umfaßt die SOFTWARE-Installation und die Anfertigung einer Sicherungskopie, das Laden der SOFTWARE in den Arbeitsspeicher und seinen Ablauf. Auf andere Nutzungsarten erstreckt sich die Lizenz nicht. Der Kunde darf insbesondere keinerlei Änderungen und Übersetzungen oder weitere Vervielfältigungen des Vektorplotters vornehmen, auch nicht teilweise oder vorübergehend, gleich welcher Art und mit welchen Mitteln. Eine unzulässige Vervielfältigung stellt auch der Ausdruck des Programmcodes dar. Änderungen, zu denen FIRMA nach Treu und Glauben die Zustimmung nicht verweigert werden kann (§ 39 Abs. 2 UrhG), sind statthaft.
(Quelle: http://www.ra-juelich.com/printable/534128972a09bec02/53412898b50b5bf01/index.php Stand: 17.02.2021)
